==> fq-0.7.0.tar.gz: fq-0.7.0/format/all/all.go <==
// Package all registers all builtin formats with the default registry
package all

import (
	_ "github.com/wader/fq/format/ape"
	_ "github.com/wader/fq/format/apple/bookmark"
	_ "github.com/wader/fq/format/apple/bplist"
	_ "github.com/wader/fq/format/apple/macho"
	_ "github.com/wader/fq/format/ar"
	_ "github.com/wader/fq/format/asn1"
	_ "github.com/wader/fq/format/av1"
	_ "github.com/wader/fq/format/avro"
	_ "github.com/wader/fq/format/bencode"
	_ "github.com/wader/fq/format/bitcoin"
	_ "github.com/wader/fq/format/bits"
	_ "github.com/wader/fq/format/bson"
	_ "github.com/wader/fq/format/bzip2"
	_ "github.com/wader/fq/format/cbor"
	_ "github.com/wader/fq/format/crypto"
	_ "github.com/wader/fq/format/csv"
	_ "github.com/wader/fq/format/dns"
	_ "github.com/wader/fq/format/elf"
	_ "github.com/wader/fq/format/fairplay"
	_ "github.com/wader/fq/format/flac"
	_ "github.com/wader/fq/format/gif"
	_ "github.com/wader/fq/format/gzip"
	_ "github.com/wader/fq/format/icc"
	_ "github.com/wader/fq/format/id3"
	_ "github.com/wader/fq/format/inet"
	_ "github.com/wader/fq/format/jpeg"
	_ "github.com/wader/fq/format/json"
	_ "github.com/wader/fq/format/luajit"
	_ "github.com/wader/fq/format/markdown"
	_ "github.com/wader/fq/format/math"
	_ "github.com/wader/fq/format/matroska"
	_ "github.com/wader/fq/format/mp3"
	_ "github.com/wader/fq/format/mp4"
	_ "github.com/wader/fq/format/mpeg"
	_ "github.com/wader/fq/format/msgpack"
	_ "github.com/wader/fq/format/ogg"
	_ "github.com/wader/fq/format/opus"
	_ "github.com/wader/fq/format/pcap"
	_ "github.com/wader/fq/format/png"
	_ "github.com/wader/fq/format/postgres"
	_ "github.com/wader/fq/format/prores"
	_ "github.com/wader/fq/format/protobuf"
	_ "github.com/wader/fq/format/riff"
	_ "github.com/wader/fq/format/rtmp"
	_ "github.com/wader/fq/format/tar"
	_ "github.com/wader/fq/format/text"
	_ "github.com/wader/fq/format/tiff"
	_ "github.com/wader/fq/format/tls"
	_ "github.com/wader/fq/format/toml"
	_ "github.com/wader/fq/format/tzif"
	_ "github.com/wader/fq/format/vorbis"
	_ "github.com/wader/fq/format/vpx"
	_ "github.com/wader/fq/format/wasm"
	_ "github.com/wader/fq/format/webp"
	_ "github.com/wader/fq/format/xml"
	_ "github.com/wader/fq/format/yaml"
	_ "github.com/wader/fq/format/zip"
)

==> fq-0.8.0.tar.gz: fq-0.8.0/format/all/all.go <==
// Package all registers all builtin formats with the default registry
package all

import (
	_ "github.com/wader/fq/format/ape"
	_ "github.com/wader/fq/format/apple/bookmark"
	_ "github.com/wader/fq/format/apple/bplist"
	_ "github.com/wader/fq/format/apple/macho"
	_ "github.com/wader/fq/format/ar"
	_ "github.com/wader/fq/format/asn1"
	_ "github.com/wader/fq/format/av1"
	_ "github.com/wader/fq/format/avro"
	_ "github.com/wader/fq/format/bencode"
	_ "github.com/wader/fq/format/bitcoin"
	_ "github.com/wader/fq/format/bits"
	_ "github.com/wader/fq/format/bson"
	_ "github.com/wader/fq/format/bzip2"
	_ "github.com/wader/fq/format/caff"
	_ "github.com/wader/fq/format/cbor"
	_ "github.com/wader/fq/format/crypto"
	_ "github.com/wader/fq/format/csv"
	_ "github.com/wader/fq/format/dns"
	_ "github.com/wader/fq/format/elf"
	_ "github.com/wader/fq/format/fairplay"
	_ "github.com/wader/fq/format/flac"
	_ "github.com/wader/fq/format/gif"
	_ "github.com/wader/fq/format/gzip"
	_ "github.com/wader/fq/format/icc"
	_ "github.com/wader/fq/format/id3"
	_ "github.com/wader/fq/format/inet"
	_ "github.com/wader/fq/format/jpeg"
	_ "github.com/wader/fq/format/json"
	_ "github.com/wader/fq/format/luajit"
	_ "github.com/wader/fq/format/markdown"
	_ "github.com/wader/fq/format/math"
	_ "github.com/wader/fq/format/matroska"
	_ "github.com/wader/fq/format/moc3"
	_ "github.com/wader/fq/format/mp3"
	_ "github.com/wader/fq/format/mp4"
	_ "github.com/wader/fq/format/mpeg"
	_ "github.com/wader/fq/format/msgpack"
	_ "github.com/wader/fq/format/ogg"
	_ "github.com/wader/fq/format/opentimestamps"
	_ "github.com/wader/fq/format/opus"
	_ "github.com/wader/fq/format/pcap"
	_ "github.com/wader/fq/format/png"
	_ "github.com/wader/fq/format/postgres"
	_ "github.com/wader/fq/format/prores"
	_ "github.com/wader/fq/format/protobuf"
	_ "github.com/wader/fq/format/riff"
	_ "github.com/wader/fq/format/rtmp"
	_ "github.com/wader/fq/format/tar"
	_ "github.com/wader/fq/format/text"
	_ "github.com/wader/fq/format/tiff"
	_ "github.com/wader/fq/format/tls"
	_ "github.com/wader/fq/format/toml"
	_ "github.com/wader/fq/format/tzif"
	_ "github.com/wader/fq/format/vorbis"
	_ "github.com/wader/fq/format/vpx"
	_ "github.com/wader/fq/format/wasm"
	_ "github.com/wader/fq/format/webp"
	_ "github.com/wader/fq/format/xml"
	_ "github.com/wader/fq/format/yaml"
	_ "github.com/wader/fq/format/zip"
)
